==> vue-plugin-kuzzle-4.3.1.tgz: package/index.ts <==
import { Kuzzle, WebSocket } from 'kuzzle-sdk';
import _Vue  from 'vue';

const LS_KEY = 'kuzzle-backend'
const GLOBAL_NAME = 'kuzzleBackend'

interface Backend {
  host: string;
  options: {
    port: number;
    sslConnection: boolean
  }
}

interface Backends {
  [name: string]: Backend
}

export function getBackendFromConf(backendsConfig: Backends) {
  const backends: Backends = {
    default: {
      host: process.env.VUE_APP_BACKEND_HOST || 'localhost',
      options: {
        port: parseInt(process.env.VUE_APP_BACKEND_PORT || '7512'),
        sslConnection: process.env.VUE_APP_BACKEND_SSL === 'true' || false
      }
    },
    ...backendsConfig
  }

  const backendName: string = process.env.VUE_APP_BACKEND
    ? process.env.VUE_APP_BACKEND
    : 'default';

    if (!backends[backendName]) {
      throw new Error(`Unable to find backend ${backendName} in configuration.`);
    }

  return backends[backendName] ? backends[backendName] : null;
}

export function getBackendFromLocalStorage() {
  const lsItem = localStorage.getItem(LS_KEY);
  if (!lsItem) {
    return null;
  }
  const backend = JSON.parse(lsItem)

  if (typeof backend !== 'object') {
    throw new Error(`Item found in localStorage (${LS_KEY}) is malformed. Expected an object, found ${backend}`)
  }

  return backend;
}

export function getBackendFromWindow() {
  if (!(window as any)[GLOBAL_NAME]) {
    return null
  }

  const backend = JSON.parse((window as any)[GLOBAL_NAME])

  if (typeof backend !== 'object') {
    throw new Error(`Item found in global (${GLOBAL_NAME}) is malformed. Expected an object, found ${backend}`)
  }

  return backend;
}

export const instantiateKuzzleSDK = (backendsConfig: Backends, sdkOptions: any): Kuzzle => {
  const backend:Backend | null = getBackendFromLocalStorage() || getBackendFromWindow() || getBackendFromConf(backendsConfig)

  if (!backend) {
    throw new Error('No backend resolved.');
  }

  if (!backend.host) {
    throw new Error(`Backend is malformed (missing host)`);
  }

  return new Kuzzle(new WebSocket(backend.host, backend.options || null), sdkOptions);
};

/**
 * The VueKuzzle plugin. Makes the Kuzzle SDK available in Vue components as
 * `this.$kuzzle`.
 * 
 * @param Vue The Vue application to apply the plugin to
 * @param options Options passed to the Kuzzle SDK constructor
 * 
 * @see https://docs.kuzzle.io/sdk/js/7/core-classes/kuzzle/constructor/#options
 */
export function VueKuzzle(Vue: typeof _Vue, options: any) {
  const sdkOptions = options.sdkOptions ? options.sdkOptions : {};
  Vue.prototype.$kuzzle = instantiateKuzzleSDK(options.backends, sdkOptions);
}

==> vue-plugin-kuzzle-4.4.0.tgz: package/index.ts <==
import { Http, Kuzzle, KuzzleAbstractProtocol, WebSocket } from 'kuzzle-sdk';
import _Vue  from 'vue';

const LS_KEY = 'kuzzle-backend'
const GLOBAL_NAME = 'kuzzleBackend'

export enum KuzzleProtocol {
  HTTP = 'http',
  WEBSOCKET = 'websocket'
}
export interface Backend {
  host: string;
  protocol: KuzzleProtocol
  options: {
    port: number;
    sslConnection: boolean,
  }
}

export interface Backends {
  [name: string]: Backend
}

export function getBackendFromConf(backendsConfig: Backends) {
  const backends: Backends = {
    default: {
      host: process.env.VUE_APP_BACKEND_HOST || 'localhost',
      protocol: (process.env.VUE_APP_BACKEND_PROTO as KuzzleProtocol) || KuzzleProtocol.WEBSOCKET,
      options: {
        port: parseInt(process.env.VUE_APP_BACKEND_PORT || '7512'),
        sslConnection: process.env.VUE_APP_BACKEND_SSL === 'true' || false
      }
    },
    ...backendsConfig
  }

  const backendName: string = process.env.VUE_APP_BACKEND
    ? process.env.VUE_APP_BACKEND
    : 'default';

    if (!backends[backendName]) {
      throw new Error(`Unable to find backend ${backendName} in configuration.`);
    }

  return backends[backendName] ? backends[backendName] : null;
}

export function getBackendFromLocalStorage() {
  const lsItem = localStorage.getItem(LS_KEY);
  if (!lsItem) {
    return null;
  }
  const backend = JSON.parse(lsItem)

  if (typeof backend !== 'object') {
    throw new Error(`Item found in localStorage (${LS_KEY}) is malformed. Expected an object, found ${backend}`)
  }

  return backend;
}

export function getBackendFromWindow() {
  if (!(window as any)[GLOBAL_NAME]) {
    return null
  }

  const backend = JSON.parse((window as any)[GLOBAL_NAME])

  if (typeof backend !== 'object') {
    throw new Error(`Item found in global (${GLOBAL_NAME}) is malformed. Expected an object, found ${backend}`)
  }

  return backend;
}

/**
 * Instantiates the Kuzzle SDK by resolving the backend from the given config.
 * 
 * @param backendsConfig 
 * @param sdkOptions 
 */
export const instantiateKuzzleSDK = (backendsConfig: Backends, sdkOptions: any): Kuzzle => {
  const backend:Backend | null = getBackendFromLocalStorage() || getBackendFromWindow() || getBackendFromConf(backendsConfig)

  if (!backend) {
    throw new Error('No backend resolved.');
  }

  if (!backend.host) {
    throw new Error(`Backend is malformed (missing host)`);
  }

  return new Kuzzle(protocolFactory(backend), sdkOptions);
};

const protocolFactory = (backend: Backend): KuzzleAbstractProtocol => {
  switch (backend.protocol) {
    case KuzzleProtocol.HTTP:
      return new Http(backend.host, backend.options)
    
    case KuzzleProtocol.WEBSOCKET:
    default:
      return new WebSocket(backend.host, backend.options)
  }
}

/**
 * The VueKuzzle plugin. Makes the Kuzzle SDK available in Vue components as
 * `this.$kuzzle`.
 * 
 * @param Vue The Vue application to apply the plugin to
 * @param options Options passed to the Kuzzle SDK constructor
 * 
 * @see https://docs.kuzzle.io/sdk/js/7/core-classes/kuzzle/constructor/#options
 */
export function VueKuzzle(Vue: typeof _Vue, options: any) {
  const sdkOptions = options.sdkOptions ? options.sdkOptions : {};
  Vue.prototype.$kuzzle = instantiateKuzzleSDK(options.backends, sdkOptions);
}
